# TQMa6\[QP,DP,Q,D,DL,SL\] up to Rev.040x on MBa6x REV.020x carrier board

[[_TOC_]]

## Overview

### Supported Hardware:

* TQMa6x: module revisions REV.010x ... REV.040x
* MBa6x:  board revisions REV.020x

### Versions

_Bootloader:_

* Mainline: u-boot v2017.11 + Patches

_Kernel:_

* Mainline: linux 5.15.55 + Patches
* Mainline + PREEMPT-RT: linux 5.15.55 + -rt48 + Patches

### Known issues

* PCIe requires a power cycle to work reliably. Asserting a reset using S9 or S10 is not sufficient.
* Backlight on parallel displays are enabled upon Power-On which might lead to random output.
  Display will be disabled during bootup and can be used normally afterwards.

## Usage

### Configuration

Configure BSP for usage with TQMa6x / MBa6x by calling:

* for linux/mainline with systemd init / Qt5:     `tools/config-mba6x`
* for linux/mainline with busybox init:           `tools/config-mba6x.tiny`

### Build

Build the BSP by calling

`./p images`

The build results are located in
`./platform-MBa6x/images`

## Artifacts

### U-Boot images

U-Boot images for TQMa6S, TQMa6DL, TQMa6\[D,Q\], TQMa6\[DP,QP\]

|                                  |                                             |
| :------------------------------- | :------------------------------------------ |
| u-boot-mba6\[s,dl,q,qp\]-mmc.imx | U-Boot for SD / e-MMC boot                  |
| u-boot-2gb-mba6q-mmc.imx         | U-Boot for SD / e-MMC boot with 2GB support |
| u-boot-mba6\[s,dl,q,qp\]-spi.imx | U-Boot for SPI NOR boot                     |

### Linux zImages

|               |                              |
| :------------ | :--------------------------- |
| linuximage    | for Mainline                 |
| linuximage-rt | for Mainline with PREEMPT-RT |

### Device tree blobs

*Note:* 

* TQMa6S and TQMa6DL use same files
* TQMa6D and TQMa6Q use same files
* TQMa6DP and TQMa6QP use same files

Files for all builds

|                                                      |                                                                     |
| :--------------------------------------------------- | :------------------------------------------------------------------ |
| imx6\[qp,q,dl\]-mba6\[a,b\].dtb                      | without display                                                     |
| imx6\[qp,q,dl\]-mba6\[a,b\]-cdtech-fc21.dtb          | with parallel / LCD display (DMB S070WS12H-O-CT21/S070PWS19HP-FC21) |
| imx6\[qp,q,dl\]-mba6\[a,b\]-cdtech-dc44.dtb          | with parallel / LCD display (DMB S070WV106H-CT44/S070SWV29HG-DC44)  |
| imx6\[qp,q,dl\]-mba6\[a,b\]-lvds-tm070jvhg33.dtb     | with LVDS display (Tianma tm070jvhg33)                              |
| imx6\[qp,q,dl\]-mba6\[a,b\]-duallvds-tm070jvhg33.dtb | with dual LVDS display (2 x Tianma tm070jvhg33)                     |
| imx6\[qp,q,dl\]-mba6\[a,b\]-hdmi.dts                 | with HDMI display                                                   |
| imx6\[qp,q,dl\]-mba6\[a,b\]-multi.dtb                | with lvds (Tianma tm070jvhg33) + HDMI display                       |

### Firmware (containing Linux zImages & Device tree blobs)

|              |
| :----------- |
| firmware.img |
| firmware.tgz |

### RootFS

|            |                                |
| :--------- | :----------------------------- |
| root.ext2  | EXT file system for SD / e-MMC |
| root.tgz   | tgz for NFS mount              |

### SD / e-MMC system images (bootloader, firmware partition, RootFS)

|                            |                                |
| :------------------------- | :----------------------------- |
| uboot\_tqma6qp\_hd.img     | TQMa6\[QP,DP\] on MBa6x        |
| uboot\_tqma6q\_hd.img      | TQMa6\[Q,D\] on MBa6x          |
| uboot\_2gb\_tqma6q\_hd.img | TQMa6\[Q,D\] with 2GB on MBa6x |
| uboot\_tqma6s\_hd.img      | TQMa6S on MBa6x                |
| uboot\_tqma6dl\_hd.img     | TQMa6DL on MBa6x               |

## HowTo

### MBa6x DIP Switch settings for Boot

_Note:_

* S1/2/4 are for BOOT_CFG.
* S5 is for Boot Mode.
* X means position of DIP, - means don't care

#### SD Card

|         |  S1  |     |      |      |      |      |      |      |    |  S2 |     |     |     |     |     |     |     |    |  S4 |     |     |     |     |     |     |     |    |  S5 |     |
| ------- | :--: | :-: | :--: | :--: | :--: | :--: | :--: | :--: | -- | :-: | :-: | :-: | :-: | :-: | :-: | :-: | :-: | -- | :-: | :-: | :-: | :-: | :-: | :-: | :-: | :-: | -- | :-: | :-: |
| DIP     |  1   |  2  |  3   |  4   |  5   |  6   |  7   |  8   |    |  1  |  2  |  3  |  4  |  5  |  6  |  7  |  8  |    |  1  |  2  |  3  |  4  |  5  |  6  |  7  |  8  |    |  1  |  2  |
| ON      |      |  x  |      |  x   |      |      |      |      |    |     |     |  x  |     |  x  |     |     |     |    |     |     |     |     |     |     |     |     |    |  x  |     |
| OFF     |  x   |     |  x   |      |  x   |  x   |  x   |  x   |    |  x  |  x  |     |  x  |     |  x  |  x  |  x  |    |  -  |  -  |  -  |  -  |  -  |  -  |  -  |  -  |    |     |  x  |

#### e-MMC

|         |  S1  |     |      |      |      |      |      |      |    |  S2 |     |     |     |     |     |     |     |    |  S4 |     |     |     |     |     |     |     |    |  S5 |     |
| ------- | :--: | :-: | :--: | :--: | :--: | :--: | :--: | :--: | -- | :-: | :-: | :-: | :-: | :-: | :-: | :-: | :-: | -- | :-: | :-: | :-: | :-: | :-: | :-: | :-: | :-: | -- | :-: | :-: |
| DIP     |  1   |  2  |  3   |  4   |  5   |  6   |  7   |  8   |    |  1  |  2  |  3  |  4  |  5  |  6  |  7  |  8  |    |  1  |  2  |  3  |  4  |  5  |  6  |  7  |  8  |    |  1  |  2  |
| ON      |      |  x  |  x   |      |      |      |      |      |    |     |  x  |     |  x  |     |     |     |     |    |     |     |     |     |     |     |     |     |    |  x  |     |
| OFF     |  x   |     |      |  x   |  x   |  x   |  x   |  x   |    |  x  |     |  x  |     |  x  |  x  |  x  |  x  |    |  -  |  -  |  -  |  -  |  -  |  -  |  -  |  -  |    |     |  x  |

#### SPI

|         |  S1  |     |      |      |      |      |      |      |    |  S2 |     |     |     |     |     |     |     |    |  S4 |     |     |     |     |     |     |     |    |  S5 |     |
| ------- | :--: | :-: | :--: | :--: | :--: | :--: | :--: | :--: | -- | :-: | :-: | :-: | :-: | :-: | :-: | :-: | :-: | -- | :-: | :-: | :-: | :-: | :-: | :-: | :-: | :-: | -- | :-: | :-: |
| DIP     |  1   |  2  |  3   |  4   |  5   |  6   |  7   |  8   |    |  1  |  2  |  3  |  4  |  5  |  6  |  7  |  8  |    |  1  |  2  |  3  |  4  |  5  |  6  |  7  |  8  |    |  1  |  2  |
| ON      |      |     |  x   |  x   |      |      |      |      |    |     |     |     |     |     |     |     |     |    |     |     |     |  x  |  x  |     |     |     |    |  x  |     |
| OFF     |  x   |  x  |      |      |  x   |  x   |  x   |  x   |    |  -  |  -  |  -  |  -  |  -  |  -  |  -  |  -  |    |  x  |  x  |  x  |     |     |  x  |  x  |  x  |    |     |  x  |


### Initially program boot loader image

#### SPI NOR

To initialize SPI NOR with bootloader write [bootloader image](#U-Boot images)
to SPI NOR at offset 0x400:

```
setenv uboot <qspi u-boot image>
tftp $loadaddr ${uboot}
sf probe
sf erase 0 80000
sf write ${loadaddr} 0x400 ${filesize}
```

#### SD / e-MMC

To initialize SD / e-MMC with bootloader, write [bootloader image](#U-Boot images)
to SD / e-MMC at offset 0x400 / block #2

```
setenv uboot <sd/e-mmc u-boot image>
tftp ${loadaddr} ${uboot}
mmc dev [0,1]
mmc rescan
setenv blkc ${filesize} + 1ff
setenv blkc ${blkc} / 200
mmc write ${loadaddr} 2 ${blkc}
setenv blkc
```

### Program complete system image

To program complete system image to SD / e-MMC, write 
[SD / e-MMC system images](#SD / e-MMC system images (bootloader, firmware partition, RootFS)) 
to SD / e-MMC at offset 0x00 / block #0

```
dd if=<SD / e-MMC system images> of=/dev/mmcblk0 bs=4k conv=fsync
```

### Update parts of system

To update parts of system using U-Boot / TFTP following shortcuts exist, to
update the part on the active boot device.

[Linux image](#Linux zImages)
```
setenv zimage <name of linux zimage>
run update_kernel
```

[Device tree blobs](#Device tree blobs)
```
setenv fdt_file <name of fdt image>
run update_fdt
```

[bootloader image](#U-Boot images)
```
setenv uboot <name of u-boot image>
run update_uboot
```

### Linux display support

To boot linux with display support, set env `fdt_file` in U-Boot to the
matching device tree blob for your display

#### Display testing:

*OpenGL:*

```
kmscube -D /dev/dri/card1
glmark2-es2-drm
```

*gstreamer:*

```
gst-play-1.0 <file>
gst-launch-1.0 playbin uri=file://<file>
gst-launch-1.0 filesrc location=/usr/share/media/video/TQ-in-20-Sekunden-720P_Rev002.mp4 ! qtdemux ! h264parse ! v4l2h264dec ! kmssink
```

*Wayland:*

If not exist, need to set enviroment variable `XDG_RUNTIME_DIR`:

```
mkdir /tmp/wayland
chmod 0700 /tmp/wayland
export XDG_RUNTIME_DIR=/tmp/wayland
```

*Weston:*

Needs an input device

```
weston --tty=1 &
glmark2-es2-wayland
gst-launch-1.0 filesrc location=/usr/share/media/video/TQ-in-20-Sekunden-720P_Rev002.mp4 ! qtdemux ! h264parse ! v4l2h264dec ! waylandsink
/usr/lib/qt5/examples/opengl/cube/cube -platform wayland-egl
```

#### Device trees for multiple displays

Additional device trees with multiple displays can be created using existing
.dtsi fragments. The device trees are under `[linux]/arch/arm/boot/dts/`.
Copy the .dts of the used display. Open the new file and add inclusion of the
needed fragment, e.g:

`#include "imx6qdl-mba6-hdmi.dtsi"`

*Note:* The first display is the primary display.

================================================================================

See [TQ Embedded Wiki for TQMa6x](https://support.tq-group.com/en/arm/tqma6x)

