# TQMa7x on MBa7x carrier board (aka STKa7x)

[[_TOC_]]

## Overview

### Supported Hardware:

* TQMa7x: module revisions REV.020x
* MBa7x:  board revisions REV.020x

### Versions

_Bootloader:_

* uboot-imx (2016.03 + rel_imx_4.1.15_2.0.0_ga + patches)

_Kernel:_

* Mainline: linux 5.15.55 + Patches
* Mainline + PREEMPT-RT: linux 5.15.55 + -rt48 + Patches

### Known issues

* USB Dual Role gadget: Causing a device disconnect is not possible. D+ is
erroneously supplying VBUS as well preventing a device disconnect per software.
Occurs when gadget is disabled again. USB host might fail to detect a new USB
descriptor once gadget is restarted.
* Using internal PCIe PHY clock is currently not supported by the Linux mainline kernel
PCIe can not be used on MBa7x

## Usage

### Configuration

Configure BSP for usage with TQMa7x / MBa7x by calling:

* for linux/mainline with busybox init without Qt:      `tools/config-mba7x.tiny`
* for linux/mainline with busybox init with Qt enabled: `tools/config-mba7x`
* for linux/mainline with systemd init without Qt:      `tools/config-mba7x.sd`

**Attention**

With the standard U-Boot environment, only one CPU core is used in the mainline kernel. 
In order to be able to use both CPUs with the TQMa7D, the secure bootmood must
be deactivated.

`bootm_boot_mode = nonsec`

The number of running CPUs can be checked with `nproc`

### Build

Build the BSP by calling

`./p images`

The build results are located in

`./platform-MBa7x/images`

## Artifacts

### U-Boot images

U-Boot images: (512MB, 1GB, 2GB RAM)

|                                            |                                           |
| :----------------------------------------- | :---------------------------------------- |
| u-boot-fsl-\[512mb,1gb,2gb\]-mba7-mmc.imx  | U-Boot for SD / e-MMC boot                |
| u-boot-fsl-\[512mb,1gb,2gb\]-mba7-qspi.imx | U-Boot for QSPI boot inkl QSPI bootstream |

### Linux zImages

|               |                              |
| :------------ | :--------------------------- |
| linuximage    | for Mainline                 |
| linuximage-rt | for Mainline with PREEMPT-RT |

### Device tree blobs

|                                         |                                                               |
| :-------------------------------------- | :------------------------------------------------------------ |
| imx7\[s,d\]-mba7.dtb                    | without display                                               |
| imx7\[s,d\]-mba7-lvds.dtb               | with LVDS display (Tianma TM070JVHG33)                        |
| imx7\[s,d\]-mba7-dmb-ct21.dtb           | with parallel display (DMB S070WS12H-O-CT21/S070PWS19HP-FC21) |
| imx7\[s,d\]-mba7-dmb-ct44.dtb           | with parallel display (DMB S070WV106H-CT44/S070SWV29HG-DC44)  |

### Firmware (containing Linux zImages & Device tree blobs)

|              |
| :----------- |
| firmware.img |
| firmware.tgz |

### RootFS

|            |                                |
| :--------- | :----------------------------- |
| root.ext2  | EXT file system for SD / e-MMC |
| root.tgz   | tgz for NFS mount              |
| root.ubifs | ubifs image for QSPI NOR       |
| root.ubi   | ubi partition for QSPI NOR     |

### SD / e-MMC system images (bootloader, firmware partition, RootFS)

|                          |                               |
| :----------------------- | :---------------------------- |
| uboot-512mb-mba7x-hd.img | TQMa7 with 512MB RAM on MBa7x |
| uboot-1gb-mba7x-hd.img   | TQMa7 with 1GB RAM on MBa7x   |
| uboot-2gb-mba7x-hd.img   | TQMa7 with 2GB RAM on MBa7x   |

### QSPI NOR System images (QSPI NOR config, bootloader, device tree, kernel)

|                            |                               |
| :------------------------- | :---------------------------- |
| uboot-512mb-mba7x-qspi.img | TQMa7 with 512MB RAM on MBa7x |
| uboot-1gb-mba7x-qspi.img   | TQMa7 with 1GB RAM on MBa7x   |
| uboot-2gb-mba7x-qspi.img   | TQMa7 with 2GB RAM on MBa7x   |

## HowTo

### MBa7x DIP Switch settings for Boot

_Note:_

* S2/3/4 are for BOOT_CFG 0..20.
* S1 is for Boot Mode.
* X means position of DIP, - means don't care

#### SD Card

|         |  S2  |     |     |     |     |     |     |     |    |  S3  |     |     |     |     |     |     |     |    |  S4 |     |     |     |    |  S1 |     |
| ------- | :--: | :-: | :-: | :-: | :-: | :-: | :-: | :-: | -- | :--: | :-: | :-: | :-: | :-: | :-: | :-: | :-: | -- | :-: | :-: | :-: | :-: | -- | :-: | :-: |
| DIP     |  1   |  2  |  3  |  4  |  5  |  6  |  7  |  8  |    |  1   |  2  |  3  |  4  |  5  |  6  |  7  |  8  |    |  1  |  2  |  3  |  4  |    |  1  |  2  |
| ON      |      |  x  |     |     |  x  |     |     |     |    |      |     |     |     |  x  |     |     |     |    |     |     |     |     |    |  x  |     |
| OFF     |  x   |     |  x  |  x  |     |  x  |  x  |  x  |    |  x   |  x  |  x  |  x  |     |  x  |  x  |  x  |    |  -  |  -  |  -  |  -  |    |     |  x  |

#### e-MMC

|         |  S2  |     |     |     |     |     |     |     |    |  S3  |     |     |     |     |     |     |     |    |  S4 |     |     |     |    |  S1 |     |
| ------- | :--: | :-: | :-: | :-: | :-: | :-: | :-: | :-: | -- | :--: | :-: | :-: | :-: | :-: | :-: | :-: | :-: | -- | :-: | :-: | :-: | :-: | -- | :-: | :-: |
| DIP     |  1   |  2  |  3  |  4  |  5  |  6  |  7  |  8  |    |  1   |  2  |  3  |  4  |  5  |  6  |  7  |  8  |    |  1  |  2  |  3  |  4  |    |  1  |  2  |
| ON      |      |     |     |     |     |  x  |     |     |    |      |     |     |  x  |     |  x  |     |     |    |     |     |     |     |    |  x  |     |
| OFF     |  x   |  x  |  x  |  x  |  x  |     |  x  |  x  |    |  x   |  x  |  x  |     |  x  |     |  x  |  x  |    |  -  |  -  |  -  |  -  |    |     |  x  |

#### QSPI

|         |  S2  |     |     |     |     |     |     |     |    |  S3  |     |     |     |     |     |     |     |    |  S4 |     |     |     |    |  S1 |     |
| ------- | :--: | :-: | :-: | :-: | :-: | :-: | :-: | :-: | -- | :--: | :-: | :-: | :-: | :-: | :-: | :-: | :-: | -- | :-: | :-: | :-: | :-: | -- | :-: | :-: |
| DIP     |  1   |  2  |  3  |  4  |  5  |  6  |  7  |  8  |    |  1   |  2  |  3  |  4  |  5  |  6  |  7  |  8  |    |  1  |  2  |  3  |  4  |    |  1  |  2  |
| ON      |      |     |     |     |     |     |     |     |    |      |     |     |     |     |     |  x  |     |    |     |     |     |     |    |  x  |     |
| OFF     |  x   |  x  |  x  |  x  |  x  |  x  |  x  |  x  |    |  x   |  x  |  x  |  x  |  x  |  x  |     |  x  |    |  -  |  -  |  -  |  -  |    | 


### Initially program boot loader image

#### QSPI NOR

##### Bootloader

To initialize QSPI NOR with bootloader write [bootloader image](#U-Boot images)
to QSPI NOR at offset 0x00:

```
setenv uboot <qspi u-boot image>
tftp ${loadaddr} ${uboot}
sf probe
sf update ${loadaddr} 0 ${filesize}
```

##### Kernel

```
setenv kernel <linux zimage>
tftp ${loadaddr} ${kernel}
sf probe
sf update ${loadaddr} ${kernel_mtdpart} ${filesize}
```

##### Device Tree

[Device tree blobs](#Device tree blobs)
```
setenv fdt_file <fdt file>
tftp ${loadaddr} ${fdt_file}
sf probe
sf update ${loadaddr} ${fdt_mtdpart} ${filesize}
```

#### SD / e-MMC

To initialize SD / e-MMC with bootloader, write [bootloader image](#U-Boot images)
to SD / e-MMC at offset 0x400 / block #2

```
setenv uboot <sd/e-mmc u-boot image>
tftp ${loadaddr} ${uboot}
mmc dev [0,1]
mmc rescan
setenv blkc ${filesize} + 1ff
setenv blkc ${blkc} / 200
mmc write ${loadaddr} 2 ${blkc}
setenv blkc
```

### Program complete system image

#### QSPI NOR

To Program complete system image to QSPI NOR, write 
[QSPI system images](#QSPI NOR System images (QSPI NOR config, bootloader, device tree, kernel))
to QSPI NOR at offset 0x00

##### U-Boot
```
tftp ${loadaddr} <qspi image>
sf probe
sf update ${loadaddr} 0 ${filesize}
```

##### Linux

To program the rootfs as UBI, write [RootFS](#RootFS) `.ubi` to
`/dev/mtd5` (under linux)

```
ubiformat /dev/mtd5 -f /<path>/root.ubi
```

To check usability of the programmed rootfs, one can use the command 
```
ubiattach /dev/ubi_ctrl -m 5
mount -t ubifs ubi0 /<mount directory>
```

#### SD / e-MMC

To program complete system image to SD / e-MMC, write
[SD / e-MMC system images](#SD / e-MMC system images (bootloader, firmware partition, RootFS))
to SD / e-MMC at offset 0x00 / block #0

```
dd if=<SD / e-MMC system images> of=/dev/mmcblk0 bs=4k conv=fsync
```

### SD / e-MMC Update parts of system

To update parts of system using U-Boot / TFTP following shortcuts exist, to
update the part on the active boot device.

[Linux image](#Linux zImages)
```
setenv zimage <name of linux zimage>
run update_kernel
```

[Device tree blobs](#Device tree blobs)
```
setenv fdt_file <name of fdt image>
run update_fdt
```

[bootloader image](#U-Boot images)
```
setenv uboot <name of u-boot image>
run update_uboot
```

### Linux display support

To boot linux with display support, set env `fdt_file` in U-Boot to the
device tree blob for your display

To use Qt with the Tianma LVDS touchscreen, you have to provide the following
env settings under linux:

`export QT_QPA_GENERIC_PLUGINS=evdevtouch,evdevmouse,evdevkeyboard`

================================================================================

See [TQ Embedded Wiki for TQMa7x](https://support.tq-group.com/en/arm/tqma7x)
