/*
 * gpio_toggle - gpio toggling example
 *
 * Copyright (C) 2016 Markus Niebel <Markus.Niebel@tq-group.com>, TQ Systems GmbH
 *
 * License:     GPLv2
 *
 *******************************************************************************
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 ******************************************************************************/

#include <ctype.h>
#include <limits.h>
#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>
#include <errno.h>
#include <getopt.h>

#include "gpio_lib.h"

void usage(const char *progname)
{
	printf("TQ GPIO toggle test\n");
	printf("usage:\n");
	printf("%s -g <nr> -l <count>\n", progname);
	printf("\t-g:\t gpio number\n");
	printf("\t-l:\t loop count or -1 for endless\n");
	printf("\tdefaults to single shot without loops\n");
}

int main(int argc, char **argv, char **envp)
{
	unsigned long gpio = ULONG_MAX;
	signed loops = 1;
	int ch;
	char *op;
	int ret = 0;

	while (-1 != (ch = getopt(argc, argv, "g:l:h"))) {
		// check to see if a single character or long option came through
		switch (ch) {
		case 'l':
			errno = 0;
			loops = strtol(optarg, &op, 10);
			if (errno) {
				ret = errno;
				fprintf(stderr, "%s: -l needs a number\n",
					argv[0]);
				usage(argv[0]);
				ret = EINVAL;
			}
			break;
		// short option 'g'
		case 'g':
			errno = 0;
			gpio = strtoul(optarg, &op, 10);
			if (errno) {
				ret = errno;
				fprintf(stderr, "%s: -g needs an unsigned number, err %d, gpio %lu\n",
					argv[0], ret, gpio);
				usage(argv[0]);
				ret = EINVAL;
			}
			break;
		case 'h':
			ret = 0;
			usage(argv[0]);
			break;
		default:
			fprintf(stderr, "%s: opt %c\n",
				argv[0], ch);
			usage(argv[0]);
			ret = EINVAL;
		}
	}

	if (gpio == ULONG_MAX) {
		usage(argv[0]);
		ret = EINVAL;
	}

	if (!ret) {
		GPIO_ToggleLoop(gpio, loops);
	}

	return ret;
}
