# -*-makefile-*-
#
# Copyright (C) 2015-2022 TQ-Systems GmbH <oss@ew.tq-group.com>, D-82229 Seefeld, Germany.
# Author: Markus Niebel
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_FIRMWARE_IMX) += firmware-imx

#
# Paths and names
#
FIRMWARE_IMX_VERSION	:= $(call remove_quotes,$(PTXCONF_FIRMWARE_IMX_VERSION))
FIRMWARE_IMX_MD5	:= $(call remove_quotes,$(PTXCONF_FIRMWARE_IMX_MD5))

FIRMWARE_IMX		:= firmware-imx-$(FIRMWARE_IMX_VERSION)
FIRMWARE_IMX_SUFFIX	:= bin
FIRMWARE_IMX_URL	:= http://www.freescale.com/lgfiles/NMG/MAD/YOCTO/$(FIRMWARE_IMX).$(FIRMWARE_IMX_SUFFIX)
FIRMWARE_IMX_SOURCE	:= $(SRCDIR)/$(FIRMWARE_IMX).$(FIRMWARE_IMX_SUFFIX)
FIRMWARE_IMX_DIR	:= $(BUILDDIR)/$(FIRMWARE_IMX)
FIRMWARE_IMX_LICENSE	:= proprietary

FIRMWARE_IMX_LICENSE_FILES	:= \
	file://COPYING;md5=8cf95184c220e247b9917e7244124c5a \
	file://EULA;md5=c1c75b3fe5305ef5ba8052a0b1c1a1a0

# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

$(FIRMWARE_IMX_SOURCE):
	@$(call targetinfo)
	@$(call get, FIRMWARE_IMX)
	@echo "************************************************************************"
	@echo "*"
	@echo "* proceeding means in any case that you read, understand and respect"
	@echo "* the license(s) of this package"
	@echo "*"
	@echo "************************************************************************"
	@echo
	$(PTXDIST_WORKSPACE)/tools/fsl-eula.sh accept $(FIRMWARE_IMX_SOURCE) $(FIRMWARE_IMX) $(BUILDDIR)

# ----------------------------------------------------------------------------
# Extract
# ----------------------------------------------------------------------------

$(STATEDIR)/firmware-imx.extract:
	@$(call targetinfo)
	$(PTXDIST_WORKSPACE)/tools/fsl-eula.sh extract $(FIRMWARE_IMX_SOURCE) $(FIRMWARE_IMX) $(BUILDDIR)
	@$(call touch)


# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------

$(STATEDIR)/firmware-imx.prepare:
	@$(call targetinfo)
	@$(call touch)

# ----------------------------------------------------------------------------
# Compile
# ----------------------------------------------------------------------------

$(STATEDIR)/firmware-imx.compile:
	@$(call targetinfo)
	cd $(FIRMWARE_IMX_DIR)/firmware/vpu && \
		vpu_convert vpu_fw_imx53.bin v4l-coda7541-imx53.bin
ifdef PTXCONF_FIRMWARE_IMX_CODA_MX6_FW_CONVERT
	cd $(FIRMWARE_IMX_DIR)/firmware/vpu && \
		vpu_convert vpu_fw_imx6q.bin v4l-coda960-imx6q.bin
	cd $(FIRMWARE_IMX_DIR)/firmware/vpu && \
		vpu_convert vpu_fw_imx6d.bin v4l-coda960-imx6dl.bin
else
	cd $(FIRMWARE_IMX_DIR)/firmware/vpu && \
		cp vpu_fw_imx6q.bin v4l-coda960-imx6q.bin
	cd $(FIRMWARE_IMX_DIR)/firmware/vpu && \
		cp vpu_fw_imx6d.bin v4l-coda960-imx6dl.bin
endif
	@$(call touch)

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------

$(STATEDIR)/firmware-imx.install:
	@$(call targetinfo)
	cd $(FIRMWARE_IMX_DIR) && \
		mkdir -p $(FIRMWARE_IMX_PKGDIR) && \
		mkdir -p $(FIRMWARE_IMX_PKGDIR)/licenses && \
		mkdir -p $(FIRMWARE_IMX_PKGDIR)/lib/firmware && \
		cp  EULA $(FIRMWARE_IMX_PKGDIR) && \
		if [ -d licenses/vpu ]; then cp  licenses/vpu/* $(FIRMWARE_IMX_PKGDIR)/licenses; fi && \
		if [ -e COPYING ]; then cp COPYING $(FIRMWARE_IMX_PKGDIR); fi
ifdef PTXCONF_FIRMWARE_IMX_SDMA
	cd $(FIRMWARE_IMX_DIR) && \
		mkdir -p $(FIRMWARE_IMX_PKGDIR)/lib/firmware/imx/sdma && \
		cp  firmware/sdma/sdma-imx53-to1.bin $(FIRMWARE_IMX_PKGDIR)/lib/firmware/imx/sdma/sdma-imx53.bin
endif
ifdef PTXCONF_FIRMWARE_IMX_CODA
	cd $(FIRMWARE_IMX_DIR) && \
		cp  firmware/vpu/v4l-*.bin $(FIRMWARE_IMX_PKGDIR)/lib/firmware
endif
ifdef PTXCONF_FIRMWARE_IMX_VPU
	@cd $(FIRMWARE_IMX_DIR) && \
		mkdir -p $(FIRMWARE_IMX_PKGDIR)/lib/firmware/vpu && \
		cp  firmware/vpu/vpu_fw*.bin $(FIRMWARE_IMX_PKGDIR)/lib/firmware/vpu
endif
	@$(call touch)

# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

$(STATEDIR)/firmware-imx.targetinstall:
	@$(call targetinfo)

	@$(call install_init, firmware-imx)
	@$(call install_fixup, firmware-imx,PRIORITY,optional)
	@$(call install_fixup, firmware-imx,SECTION,base)
	@$(call install_fixup, firmware-imx,AUTHOR,"Markus Niebel, TQ-Systems GmbH")
	@$(call install_fixup, firmware-imx,DESCRIPTION,missing)

	@$(call install_tree, firmware-imx, 0, 0, -, /lib)

	@$(call install_finish, firmware-imx)

	@$(call touch)


# vim: syntax=make
