# -*-makefile-*-
#
# Copyright (C) 2019-2022 TQ-Systems GmbH <oss@ew.tq-group.com>, D-82229 Seefeld, Germany.
# Author: Markus Niebel, Michael Krummsdorf
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_FIRMWARE_PRU) += firmware-pru

#
# Paths and names
#
FIRMWARE_PRU_VERSION	:= ti2019.00-rc3
FIRMWARE_PRU_MD5	:= a8b9bcd5fbc37a69ca0fac6575a3f4be
FIRMWARE_PRU		:= firmware-pru-$(FIRMWARE_PRU_VERSION)
FIRMWARE_PRU_SUFFIX	:= tar.xz
FIRMWARE_PRU_DIR	:= $(BUILDDIR)/$(FIRMWARE_PRU)
FIRMWARE_PRU_LICENSE	:= proprietary
FIRMWARE_PRU_URL	:= git://git.ti.com/processor-firmware/ti-linux-firmware.git;tag=$(FIRMWARE_PRU_VERSION)
FIRMWARE_PRU_SOURCE	:= $(SRCDIR)/$(FIRMWARE_PRU).$(FIRMWARE_PRU_SUFFIX)

FIRMWARE_PRU_LICENSE_FILES	:= \
	file://LICENSE.ti;md5=b5aebf0668bdf95621259288c4a46d76

# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

$(FIRMWARE_PRU_SOURCE):
	@$(call targetinfo)
	@$(call get, FIRMWARE_PRU)
	@echo "************************************************************************"
	@echo "*"
	@echo "* proceeding means in any case that you read, understand and respect"
	@echo "* the license(s) of this package"
	@echo "*"
	@echo "************************************************************************"
	@echo

# ----------------------------------------------------------------------------
# Extract
# ----------------------------------------------------------------------------

$(STATEDIR)/firmware-pru.extract:
	@$(call targetinfo)
	@mkdir -p $(FIRMWARE_PRU_DIR) && \
		tar -xvC $(BUILDDIR) -f $(FIRMWARE_PRU_SOURCE)
	@$(call touch, FIRMWARE_PRU)

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------

$(STATEDIR)/firmware-pru.prepare:
	@$(call targetinfo)
	@$(call touch, FIRMWARE_PRU)

# ----------------------------------------------------------------------------
# Compile
# ----------------------------------------------------------------------------

$(STATEDIR)/firmware-pru.compile:
	@$(call targetinfo)
	@$(call touch, FIRMWARE_PRU)

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------

$(STATEDIR)/firmware-pru.install:
	@$(call targetinfo)
	@mkdir -p $(FIRMWARE_PRU_PKGDIR)/lib/firmware/ti-pruss && \
	cp $(FIRMWARE_PRU_DIR)/ti-pruss/am57xx-pru0-prueth-fw.elf $(FIRMWARE_PRU_PKGDIR)/lib/firmware/ti-pruss && \
	cp $(FIRMWARE_PRU_DIR)/ti-pruss/am57xx-pru1-prueth-fw.elf $(FIRMWARE_PRU_PKGDIR)/lib/firmware/ti-pruss
	@$(call touch)

# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

$(STATEDIR)/firmware-pru.targetinstall:
	@$(call targetinfo)

	@$(call install_init, firmware-pru)
	@$(call install_fixup, firmware-pru,PRIORITY,optional)
	@$(call install_fixup, firmware-pru,SECTION,base)
	@$(call install_fixup, firmware-pru,AUTHOR,"Michael Krummsdorf, TQ-Systems GmbH")
	@$(call install_fixup, firmware-pru,DESCRIPTION,missing)

	@$(call install_tree, firmware-pru, 0, 0, -, /lib/firmware/ti-pruss, no)

	@$(call install_finish, firmware-pru)

	@$(call touch)


# vim: syntax=make
