# -*-makefile-*-
#
# Copyright (C) 2012 by Tom Barth
#
# Copyright (C) 2015-2022 TQ-Systems GmbH <oss@ew.tq-group.com>, D-82229 Seefeld, Germany.
# Author: Markus Niebel
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_TQ_EXAMPLES) += tq-examples

#
# Paths and names
#
TQ_EXAMPLES_VERSION	:= 0.7.1
TQ_EXAMPLES_MD5		:=
TQ_EXAMPLES		:= tq-examples
TQ_EXAMPLES_SUFFIX	:= 
TQ_EXAMPLES_URL		:= file://$(PTXDIST_WORKSPACE)/local_src/$(TQ_EXAMPLES)
TQ_EXAMPLES_DIR		:= $(BUILDDIR)/$(TQ_EXAMPLES)

TQ_EXAMPLES_LICENSE	:= GPL-2.0
TQ_EXAMPLES_LICENSE_FILES := \
	file://COPYING;md5=0d80f2ab3d3f613e9853f13864203c46

# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

$(TQ_EXAMPLES_SOURCE):
	@$(call targetinfo)
	@$(call touch)

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------
TQ_EXAMPLES_CONF_TOOL	:= NO
TQ_EXAMPLES_PATH	:= PATH=$(CROSS_PATH)

#
# simple makefile
#
$(STATEDIR)/tq-examples.prepare:
	@$(call targetinfo)
	@$(call touch)

ifdef PTXCONF_TQ_EXAMPLES_LED
TQ_EXAMPLES_DIRLIST  += led
endif

ifdef PTXCONF_TQ_EXAMPLES_PWM
TQ_EXAMPLES_DIRLIST += pwm
endif

ifdef PTXCONF_TQ_EXAMPLES_TEMP
TQ_EXAMPLES_DIRLIST += eth
endif

ifdef PTXCONF_TQ_EXAMPLES_GPIO
TQ_EXAMPLES_DIRLIST += gpio
endif

ifdef PTXCONF_TQ_EXAMPLES_FB
TQ_EXAMPLES_DIRLIST += fb
endif

ifdef PTXCONF_TQ_EXAMPLES_USB
TQ_EXAMPLES_DIRLIST += usb
endif

ifdef PTXCONF_TQ_EXAMPLES_WDOG
TQ_EXAMPLES_DIRLIST += wdog
endif

# ----------------------------------------------------------------------------
# Compile
# ----------------------------------------------------------------------------
TQ_EXAMPLES_OPT	:= \
	CROSS_COMPILE=$(PTXCONF_COMPILER_PREFIX) \
	DIRLIST="$(TQ_EXAMPLES_DIRLIST)" \
	prefix=/usr \
	all

TQ_EXAMPLES_MAKE_ENV	:= \
	$(CROSS_ENV) \
	CPPFLAGS=-I$(KERNEL_HEADERS_INCLUDE_DIR) $(CROSS_CPPFLAGS) \
	prefix=/usr \
	LDFLAGS=$(CROSS_CPPFLAGS)

TQ_EXAMPLES_MAKE_PAR	:= NO

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------
TQ_EXAMPLES_INSTALL_ENV	:= \
	DIRLIST="$(TQ_EXAMPLES_DIRLIST)" \
	prefix=/usr \
	$(CROSS_ENV)

TQ_EXAMPLES_INSTALL_OPT	:= \
			install
# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

$(STATEDIR)/tq-examples.targetinstall:
	@$(call targetinfo)

	@$(call install_init, tq-examples)
	@$(call install_fixup, tq-examples,PRIORITY,optional)
	@$(call install_fixup, tq-examples,SECTION,base)
	@$(call install_fixup, tq-examples,AUTHOR,"Tom Barth")
	@$(call install_fixup, tq-examples,DESCRIPTION,missing)
ifdef PTXCONF_TQ_EXAMPLES_GPIO
	@$(call install_copy, tq-examples, 0, 0, 0755, -,/usr/bin/gpio_test)
	@$(call install_copy, tq-examples, 0, 0, 0755, -,/usr/bin/gpio_irq)
	@$(call install_copy, tq-examples, 0, 0, 0755, -,/usr/bin/gpio_toggle)
	@$(call install_copy, tq-examples, 0, 0, 0644, -,/usr/bin/imx-gpio.sh)
endif
ifdef PTXCONF_TQ_EXAMPLES_FB
	@$(call install_copy, tq-examples, 0, 0, 0755, -, /usr/bin/fb16)
	@$(call install_copy, tq-examples, 0, 0, 0755, -, /usr/bin/fbclr)
endif
ifdef PTXCONF_TQ_EXAMPLES_BL
	@$(call install_copy, tq-examples, 0, 0, 0755, -, /usr/bin/blconfig)
endif
ifdef PTXCONF_TQ_EXAMPLES_PWM
	@$(call install_copy, tq-examples, 0, 0, 0755, -, /usr/bin/pwmconfig)
endif
ifdef PTXCONF_TQ_EXAMPLES_LED
	@$(call install_copy, tq-examples, 0, 0, 0755, -, /usr/bin/ledconfig)
endif
ifdef PTXCONF_TQ_EXAMPLES_TEMP
	@$(call install_copy, tq-examples, 0, 0, 0755, -, /usr/bin/tempsensor)
endif
ifdef PTXCONF_TQ_EXAMPLES_USB
	@$(call install_copy, tq-examples, 0, 0, 0755, -, /usr/bin/usb-porttest)
endif
ifdef PTXCONF_TQ_EXAMPLES_WDOG
	@$(call install_copy, tq-examples, 0, 0, 0755, -, /usr/bin/watchdog_test)
endif
	@$(call install_finish, tq-examples)

	@$(call touch)

# ----------------------------------------------------------------------------
# Clean
# ----------------------------------------------------------------------------

$(STATEDIR)/tq-examples.clean:
	@$(call targetinfo)
	@-cd $(TQ_EXAMPLES_DIR) && make clean
	@$(call clean_pkg, TQ_EXAMPLES)

# vim: syntax=make
