#!/bin/bash
# SPDX-License-Identifier: GPL-2.0-or-later
#
# File:        config.sh
#
# Copyright (C) 2014-2022 TQ-Systems GmbH <oss@ew.tq-group.com>, D-82229 Seefeld, Germany.
# Author: Markus Niebel
#
# Description: A utility script that configures the BSP.
#
###############################################################################

# DEBUGGING
# set -e
set -C # noclobber

readonly PROGRAM="$(basename ${0})"
readonly SCRIPT_LIBDIR="$(dirname ${0})"

source ${SCRIPT_LIBDIR}/tools_lib_ptxdist.sh

function usage () {
    echo "Usage is as follows:"
    echo
    echo "${PROGRAM} <--usage|--help|-?>"
    echo "    Prints this usage output and exits."
    echo
    echo "    --platform <name> specifies platform to be used"
    echo "    --config <name> configuration to be used"
    echo "    --collection <name> collection to be used"
}

# RETURN VALUES/EXIT STATUS CODES
readonly E_BAD_OPTION=254
readonly E_UNKNOWN=255

main () {
	local PLATFORM=
	local CONFIG=
	local COLLECTION=

	# Process command-line arguments.
	while test $# -gt 0; do
	    case $1 in
		--platform )
		    shift
		    PLATFORM="$1"
		    shift
		    ;;
		--config )
		    shift
		    CONFIG="$1"
		    shift
		    ;;
		--collection )
		    shift
		    COLLECTION="$1"
		    shift
		    ;;

		-? | --usage | --help )
		    usage
		    exit
		    ;;

		-* )
		    echo "Unrecognized option: $1" >&2
		    usage
		    exit $E_BAD_OPTION
		    ;;

		* )
		    break
		    ;;
	    esac
	done

	local PLATFORMCONFIG=configs/platform-tq-${PLATFORM}/platformconfig
	local PTXCONFIG=configs/platform-tq-${PLATFORM}/../${CONFIG}
	! [ -z ${COLLECTION} ] && COLLECTION=configs/platform-tq-${PLATFORM}/../${COLLECTION}

	check_ptxdist

	check_config_files ${PLATFORMCONFIG} ${PTXCONFIG} ${COLLECTION}

	apply_config ${PLATFORMCONFIG} ${PTXCONFIG} ${COLLECTION}

	local CONFIG_FILE_VERSION=$(get_ptxconfig_version)

	local PLATFORM_FILE_VERSION=$(get_platformconfig_version)

	if [ "${CONFIG_FILE_VERSION}" != "${PLATFORM_FILE_VERSION}" ]; then
		echo "${CONFIG_FILE_VERSION} != ${PLATFORM_FILE_VERSION}.";
		echo "platform and config versions differ! Please correct.";
		exit $E_UNKNOWN;
	fi

	check_ptxdist_version ${CONFIG_FILE_VERSION}

	exit 0
}

main $@

