#!/bin/bash
# SPDX-License-Identifier: GPL-2.0-or-later
#
# File:        install_packages.sh
#
# Copyright (C) 2015-2022 TQ-Systems GmbH <oss@ew.tq-group.com>, D-82229 Seefeld, Germany.
# Author: Markus Niebel
#
# Description: A utility script that installs dev packages to its configured
#              locations.
#
#              install_packages.sh to copy dec packages from platform-<name> to
#              PTXCONF_PROJECT_DEVPKGDIR
#
###############################################################################

# DEBUGGING
# set -e
set -C # noclobber

readonly PROGRAM="$(basename ${0})"
readonly SCRIPT_LIBDIR="$(dirname ${0})"

source ${SCRIPT_LIBDIR}/tools_lib_ptxdist.sh

function usage () {
    echo "Usage is as follows:"
    echo
    echo "$PROGRAM <--usage|--help|-?>"
    echo "    Prints this usage output and exits."
    echo "$PROGRAM"
    echo "    copy dev packages from platform-<name> to"
    echo "    PTXCONF_PROJECT_DEVPKGDIR"
    echo
}

# RETURN VALUES/EXIT STATUS CODES
readonly E_BAD_OPTION=254
readonly E_UNKNOWN=255

main() {
	check_ptxdist

	local CONFIG_FILE_VERSION=$(get_ptxconfig_version)
	local PLATFORM_FILE_VERSION=$(get_platformconfig_version)

	if [ "x${CONFIG_FILE_VERSION}" != "x${PLATFORM_FILE_VERSION}" ]; then
		echo "platform and config versions differ! Please correct.";
		exit $E_UNKNOWN;
	fi

	check_ptxdist_version ${CONFIG_FILE_VERSION}

	local PLATFORM_NAME=$(get_platform_name)
	echo "using $PLATFORM_NAME"

	local PLATFORM=platform-${PLATFORM_NAME}
	echo "using $PLATFORM"

	local PTXDIST=ptxdist-${CONFIG_FILE_VERSION}

	local PROJECT_DEVPKGDIR=$(get_ptxconfig_var PTXCONF_PROJECT_DEVPKGDIR)
	if [ -z "${PROJECT_DEVPKGDIR}" ]; then
		echo "no PROJECT_DEVPKGDIR configured! Please correct.";
		exit $E_UNKNOWN;
	fi

	echo "using PROJECT_DEVPKGDIR: ${PROJECT_DEVPKGDIR}"

	# copy devpackages only if enabled
	local PROJECT_DEVPKG=$(get_ptxconfig_var PTXCONF_PROJECT_CREATE_DEVPKGS)
	if [ "${?}" -eq "0" ]; then
		mkdir -p ${PROJECT_DEVPKGDIR};
		if [ -d ${PROJECT_DEVPKGDIR} ]; then
			cp --preserve=mode,ownership,timestamps --no-dereference \
				--update ${PLATFORM}/packages/*-dev.tar.gz \
				${PROJECT_DEVPKGDIR};
		else
			echo "${PROJECT_DEVPKGDIR} not created or not a directory! Please correct.";
			exit $E_UNKNOWN;
		fi
	else
		echo "no packages created, please enable PTXCONF_PROJECT_CREATE_DEVPKGS.";
		exit $E_UNKNOWN;
	fi

	return 0
}

main ${@}

